
//----------------------------------------------------------------------------------------
// Final Burn Alpha Chip-8/Super Chip Driver Module (1.0)
// 
// To-Do:
//	Add proper beep
//	Add color support for 16-bit depth
//	Fix "Scroll test" (not scroll test modified)
//
//----------------------------------------------------------------------------------------

#include "burnint.h"

//#define debug

// I don't know anything about sound and this system really just makes
// beeps. So I'm using the windows sounds to produce a 'beep.'
#define USE_WINDOWS_BEEP

#define HARDWARE_CHIP8_CHIP8X		0x2000
#define HARDWARE_CHIP8_HYBRID		0x4000
#define HARDWARE_CHIP8_SUPERCHIP	0x8000

int game_type;			// 0 for Chip-8, 1 for Super Chip
unsigned short nC8Len;
unsigned char *mem;		// total memory
int screen_size;
unsigned char *screen;
unsigned short key;

int chip8_Reset();

#ifdef USE_WINDOWS_BEEP
extern "C" int __stdcall MessageBeep(int);
#endif


//----------------------------------------------------------------------------------------
// Font sprites


static unsigned char fonts[0x50] =
{
	0xF0, 0x90, 0x90, 0x90, 0xF0,	// 0
	0x20, 0x60, 0x20, 0x20, 0x70,	// 1
	0xF0, 0x10, 0xF0, 0x80, 0xF0,	// 2
	0xF0, 0x10, 0xF0, 0x10, 0xF0,	// 3
	0x90, 0x90, 0xF0, 0x10, 0x10,	// 4
	0xF0, 0x80, 0xF0, 0x10, 0xF0,	// 5
	0xF0, 0x80, 0xF0, 0x90, 0xF0,	// 6
	0xF0, 0x10, 0x20, 0x40, 0x40,	// 7
	0xF0, 0x90, 0xF0, 0x90, 0xF0,	// 8
	0xF0, 0x90, 0xF0, 0x10, 0xF0,	// 9
	0xF0, 0x90, 0xF0, 0x90, 0x90,	// A
	0xE0, 0x90, 0xE0, 0x90, 0xE0,	// B
	0xF0, 0x80, 0x80, 0x80, 0xF0,	// C
	0xE0, 0x90, 0x90, 0x90, 0xE0,	// D
	0xF0, 0x80, 0xF0, 0x80, 0xF0,	// E
	0xF0, 0x80, 0xF0, 0x80, 0x80 	// F
};


//----------------------------------------------------------------------------------------
// input functions


unsigned char chip8Reset = 0;
unsigned char chip8inp[16] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
unsigned char chip8Dip[2] = {0, 0};


static struct BurnInputInfo chip8InputList[] =
{
	{"P1 0", BIT_DIGITAL, chip8inp + 0x00, "0"},
	{"P1 1", BIT_DIGITAL, chip8inp + 0x01, "1"},
	{"P1 2", BIT_DIGITAL, chip8inp + 0x02, "2"},
	{"P1 3", BIT_DIGITAL, chip8inp + 0x03, "3"},
	{"P1 4", BIT_DIGITAL, chip8inp + 0x04, "4"},
	{"P1 5", BIT_DIGITAL, chip8inp + 0x05, "5"},
	{"P1 6", BIT_DIGITAL, chip8inp + 0x06, "6"},
	{"P1 7", BIT_DIGITAL, chip8inp + 0x07, "7"},
	{"P1 8", BIT_DIGITAL, chip8inp + 0x08, "8"},
	{"P1 9", BIT_DIGITAL, chip8inp + 0x09, "9"},
	{"P1 A", BIT_DIGITAL, chip8inp + 0x0a, "A"},
	{"P1 B", BIT_DIGITAL, chip8inp + 0x0b, "B"},
	{"P1 C", BIT_DIGITAL, chip8inp + 0x0c, "C"},
	{"P1 D", BIT_DIGITAL, chip8inp + 0x0d, "D"},
	{"P1 E", BIT_DIGITAL, chip8inp + 0x0e, "E"},
	{"P1 F", BIT_DIGITAL, chip8inp + 0x0f, "F"},

	{"Reset", BIT_DIGITAL, &chip8Reset, "reset"},

	{"Chip8 settings", BIT_DIPSWITCH, chip8Dip + 0, "dip"},
	{"Per game fix/setting", BIT_DIPSWITCH, chip8Dip + 1, "dip"},
};

STDINPUTINFO(chip8);


// Settings
static struct BurnDIPInfo chip8DIPList[] =
{
	// Defaults
	{0x11, 0xFF, 0xFF, 0x00, NULL},

	{0x00, 0xFE, 0x00,    9, "Color select"},
	{0x11, 0x01, 0x0F, 0x00, "Black and White"},
	{0x11, 0x01, 0x0F, 0x01, "Blue on green-ish"},
	{0x11, 0x01, 0x0F, 0x02, "Light blue on blue"},
	{0x11, 0x01, 0x0F, 0x03, "White on blue"},
	{0x11, 0x01, 0x0F, 0x04, "Green on dark green"},
	{0x11, 0x01, 0x0F, 0x05, "Yellow on black"},
	{0x11, 0x01, 0x0F, 0x06, "Orange on dark red"},
	{0x11, 0x01, 0x0F, 0x07, "Lt bluegray on dark bluegray"},
	{0x11, 0x01, 0x0F, 0x08, "Light gray on dark gray"},
};

STDDIPINFO(chip8);


// Set up fake dipswitches to set difficulty for Loopz
static struct BurnDIPInfo LoopzDIPList[] =
{
	// Defaults
	{0x12, 0xFF, 0xFF, 0x00, NULL},

	{0   , 0xFE, 0   ,   10, "Difficulty"},
	{0x12, 0x01, 0x0F, 0x00, "0"},
	{0x12, 0x01, 0x0F, 0x01, "1"},
	{0x12, 0x01, 0x0F, 0x02, "2"},
	{0x12, 0x01, 0x0F, 0x03, "3"},
	{0x12, 0x01, 0x0F, 0x04, "4"},
	{0x12, 0x01, 0x0F, 0x05, "5"},
	{0x12, 0x01, 0x0F, 0x06, "6"},
	{0x12, 0x01, 0x0F, 0x07, "7"},
	{0x12, 0x01, 0x0F, 0x08, "8"},
	{0x12, 0x01, 0x0F, 0x09, "9"},
};

STDDIPINFOEXT(Loopz, Loopz, chip8);

//----------------------------------------------------------------------------------------
// draw functions


// stolen from Fish'n'chips (the last one is based on Flip8's colors)
unsigned int tints[9][2] =
{
	{ 0x000000, 0xFFFFFF }, // standard	(black & white)
	{ 0xCADD5C, 0x3C4176 }, // hp48		(blue on green-ish)
	{ 0x4040E0, 0xA0A1FE }, // c64		(light blue on blue)
	{ 0x2424FF, 0xFFFFFF }, // msx		(white on blue)
	{ 0x103810, 0x10B010 }, // green	(green on dark green)
	{ 0x000000, 0xFFFF00 }, // samor	(yellow on black)
	{ 0xA41000, 0xFF631f }, // car radio 1	(orange on dark red)	
	{ 0x212435, 0xD2D4E0 }, // car radio 2	(light blue-ish gray on dark blue-ish gray)
	{ 0x343234, 0x9CCE9C }, // Flip8	(light green on dark gray)
};


int chip8draw()
{
	unsigned int *color = tints[chip8Dip[0]];

	for (int i = 0; i < screen_size * nBurnBpp; i+=nBurnBpp)
	{
		if (nBurnBpp > 2)	// color
		{
			*((unsigned int*)(pBurnDraw + i)) = color[screen[i / nBurnBpp]];
		}
		else			// b&w only atm
		{
			*((unsigned short*)(pBurnDraw + i)) = screen[i / nBurnBpp] ? ~0 : 0;
		}
	}

	return 0;
}


//----------------------------------------------------------------------------------------
// opcode emulator


unsigned short PC;		// Pointer
unsigned short ia;		// Address Register
unsigned char v[16];		// Registers
unsigned char hpr[8];		// HP48 registers
unsigned char SP;		// Stack Pointer
unsigned short stack[16];	// Stack

int draw_mode;			// Draw mode (SChip)
unsigned char deltimer;		// Delay timer
unsigned char sndtimer;		// Sound timer

int opcode_do(unsigned short op)
{
	unsigned char a, b, c, d;

	a = (op >> 12) & 0x0f;
	b = (op >>  8) & 0x0f;
	c = (op >>  4) & 0x0f;
	d = (op >>  0) & 0x0f;

#ifdef debug
	bprintf (PRINT_NORMAL, _T("%3.3x  %4.4x  "), PC, op);
#endif
	switch(a)
	{
		case 0x00:
		{
			if (b == 0)
			{
				if ((op & 0xfff0) == 0x00C0)	// SChip only
				{
					if (game_type)
					{
						if (draw_mode == 0) d >>= 1;
#ifdef debug
						bprintf (PRINT_NORMAL, _T("Scroll screen down %d lines\n"), d);
#endif
						memcpy (screen + (d * 128), screen, 0x2000 - (d * 128));
						memset (screen, 0, d * 128);

						if (!draw_mode)
						{
							memset (screen + screen_size / 2, 0, d * 128);
						}

						PC += 2;
						return 0;	// Draw frame
					}
				}
				else if (op == 0x00E0)
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("Clear screen\n"));
#endif
					memset (screen, 0, screen_size);

					PC += 2;
					return 1;
				}
				else if (op == 0x00EE)
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("Return from sub\n"));
#endif
					SP++;
					PC = stack[SP & 0x0f];

					PC+=2;
					return 1;
				}
				else if (op == 0x00FD)	// Schip only
				{
					if (game_type)
					{
#ifdef debug
						bprintf (PRINT_NORMAL, _T("Quit! (Reset instead)\n"));
#endif
						chip8_Reset();
						return 1;
					}
					
				}
				else if (op == 0x00FB)	// SChip only
				{
					if (game_type)
					{
						int dw = 2 << draw_mode;
#ifdef debug
						bprintf (PRINT_NORMAL, _T("Scroll screen right %d pxls\n"), dw);
#endif
						for (int i = 0; i < screen_size; i+= 32 * dw)
						{
							memcpy (screen + i + dw, screen + i, (32 * dw) - dw);
							memset (screen + i, 0, dw);
						}

						PC += 2;
						return 0;	// Draw frame
					}
				}
				else if (op == 0x00FC)	// SChip only
				{
					if (game_type)
					{
						int dw = 2 << draw_mode;
#ifdef debug
						bprintf (PRINT_NORMAL, _T("Scroll screen left %d pxls\n"), dw);
#endif
						for (int i = 0; i < screen_size; i+= 32 * dw)
						{
							memcpy (screen + i, screen + i + dw, (32 * dw) - dw);
							memset (screen + i + (32 * dw) - dw, 0, dw);
						}

						PC += 2;
						return 0;	// Draw frame
					}
				}
				else if (op == 0x00FE)	// SChip only
				{
					if (game_type)
					{
#ifdef debug
						bprintf (PRINT_NORMAL, _T("Set Chip-8 display mode\n"));
#endif
						draw_mode = 0;

						PC += 2;
						return 1;
					}
				}
				else if (op == 0x00FF)	// SChip only
				{
					if (game_type)
					{
#ifdef debug
						bprintf (PRINT_NORMAL, _T("Set S-Chip-8 display mode\n"));
#endif
						draw_mode = 1;

						PC += 2;
						return 1;
					}
				}
			}
			else
			{
#ifdef debug
				bprintf (PRINT_NORMAL, _T("RCA 1082 Program (not implemented)\n"));
#endif
				PC += 2;
				return 1;
			}

#ifdef debug
			bprintf (PRINT_NORMAL, _T("Undocumented opcode (nop)\n"));
#endif
			PC += 2;
			return 1;
		}

		case 0x01:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("PC = (op) %3.3x (jump)\n"), op & 0xfff);
#endif
			PC = op & 0xfff;

			return 1;
		}

		case 0x02:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("PC = (op) %3.3x (jump to sub)\n"), op & 0xfff);
#endif
			stack[SP & 0x0f] = PC;
			SP--;

			PC = op & 0xfff;
			return 1;
		}

		case 0x03:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("v[%x] (%2.2x) == op(%2.2x)\n"), b, v[b], op & 0xff);
#endif
			if (v[b] == (op & 0xff))
			{
				PC += 2;
			}

			PC += 2;
			return 1;
		}

		case 0x04:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("v[%x] (%2.2x) != op(%2.2x)\n"), b, v[b], op & 0xff);
#endif
			if (v[b] != (op & 0xff))
			{
				PC += 2;
			}

			PC += 2;
			return 1;
		}

		case 0x05:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("v[%x] (%2.2x) == v[%x] (%2.2x)\n"), b, v[b], c, v[c]);
#endif
			if (v[b] == v[c])
			{
				PC += 2;
			}

			PC += 2;
			return 1;
		}

		case 0x06:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("v[%x] = op(%2.2x)\n"), b, op & 0xff);
#endif
			v[b] = op & 0xff;

			PC += 2;
			return 1;
		}

		case 0x07:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("v[%x] = %2.2x + op(%2.2x)\n"), b, v[b], op & 0xff);
#endif
			v[b] += op & 0xff;

			PC += 2;
			return 1;
		}

		case 0x08:
		{
			switch (d)
			{
				case 0x00:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[%x] = %2.2x (v[%x]) + %2.2x (v[%x])\n"), b, v[b], b, v[c], c);
#endif
					v[b] = v[c];

					PC += 2;
					return 1;
				}

				case 0x01:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[%x] = %2.2x (v[%x]) | %2.2x (v[%x])\n"), b, v[b], b, v[c], c);
#endif
					v[b] |= v[c];

					PC += 2;
					return 1;
				}

				case 0x02:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[%x] = %2.2x (v[%x]) & %2.2x (v[%x])\n"), b, v[b], b, v[c], c);
#endif
					v[b] &= v[c];

					PC += 2;
					return 1;
				}

				case 0x03:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[%x] = %2.2x (v[%x]) ^ %2.2x (v[%x])\n"), b, v[b], b, v[c], c);
#endif
					v[b] ^= v[c];

					PC += 2;
					return 1;
				}

				case 0x04:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[%x] = %2.2x (v[%x]) + %2.2x (v[%x])\n"), b, v[b], b, v[c], c);
#endif
					v[0x0f] = ((v[b] + v[c]) >> 8) & 1;
					v[b] += v[c];

					PC += 2;
					return 1;
				}

				case 0x05:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[%x] = %2.2x (v[%x]) - %2.2x (v[%x])\n"), b, v[b], b, v[c], c);
#endif
					v[0x0f] = v[b] >= v[c];
					v[b] -= v[c];

					PC += 2;
					return 1;
				}

				case 0x06:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[%x] = %2.2x >> 1\n"), b, v[b]);
#endif
					v[0x0f] = v[b] & 1;
					v[b] >>= 1;

					PC += 2;
					return 1;
				}

				case 0x07:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[%x] = %2.2x (v[%x]) - %2.2x (v[%x])\n"), c, v[c], c, v[b], b);
#endif
					v[0x0f] = v[c] >= v[b];
					v[b] = v[c] - v[b];

					PC += 2;
					return 1;
				}

				case 0x0E:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[%x] = %2.2x << 1\n"), b, v[b]);
#endif
					v[0x0f] = (v[b] >> 7) & 1;
					v[b] <<= 1;

					PC += 2;
					return 1;
				}
			}
#ifdef debug
			bprintf (PRINT_NORMAL, _T("Undocumented opcode (nop)\n"));
#endif
			PC += 2;
			return 1;
		}

		case 0x09:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("v[%x] (%2.2x) != v[%x] (%2.2x)\n"), b, v[b], c, v[c]);
#endif
			if (v[b] != v[c])
			{
				PC += 2;
			}

			PC += 2;
			return 1;
		}

		case 0x0A:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("I = op(%3.3x)\n"), op & 0xfff);
#endif
			ia = op & 0xfff;

			PC += 2;
			return 1;
		}

		case 0x0B:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("PC = op(%3.3x) + v[%x] (%2.2x) (jump)\n"), op & 0xfff, b, v[b]);
#endif
			PC = (op & 0xfff) + v[0];
			PC &= 0xFFF;

			return 1;
		}

		case 0x0C:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("v[%x] = RAND & %2.2x\n"), b, op & 0xff);
#endif
			v[b] = rand() & (op & 0xff);

			PC += 2;
			return 1;
		}

		case 0x0D:
		{
#ifdef debug
			bprintf (PRINT_NORMAL, _T("Draw sprite X: %2.2x, Y: %2.2x, H: %x\n"), v[b], v[c], d);
#endif
			int ext = 1;
			int h = d, w = 8;

			if (d == 0 && game_type)	// SChip
			{
				h = 16;
				w <<= draw_mode;
				ext <<= draw_mode; // correct
			}

			v[0x0f] = 0;

			int x, y, j;
			for (y = 0; y < h; y++)
			{
				for (x = 0; x < w; x++)
				{
				      	if (((mem[ia + (y * ext)] << 8) | mem[ia + (y * ext) + 1]) & (0x8000 >> x) )
					{
						if (draw_mode)
						{
							j = (((v[c] + y) & 0x3f) << 7) | ((v[b] + x) & 0x7f);
						}
						else
						{
							j = (((v[c] + y) & 0x1f) << (6 + game_type)) | ((v[b] + x) & 0x3f);
						}
	
						if (screen[j] == 1)
							v[0x0f] = 1;
			
						screen[j] ^= 1;
					}
				}
			}

			PC += 2;
			return 1;
		}

		case 0x0E:
		{
			if ((op & 0xff) == 0x9E)
			{
#ifdef debug
				bprintf (PRINT_NORMAL, _T("v[%x] (%4.4x) == key (%4.4x)\n"), b, (1<<b), key);
#endif
				if ( key & (1 << v[b]))
					PC += 2;

				PC += 2;
				return 1;
			}

			if ((op & 0xff) == 0xA1)
			{
#ifdef debug
				bprintf (PRINT_NORMAL, _T("v[%x] (%4.4x) != key (%4.4x)\n"), b, (1<<b), key);
#endif
				if (~key & (1 << v[b]))
					PC += 2;

				PC += 2;
				return 1;
			}

#ifdef debug
			bprintf (PRINT_NORMAL, _T("Undocumented opcode (nop)\n"));
#endif
			PC += 2;
			return 1;
		}

		case 0x0F:
		{
			switch (op & 0xff)
			{
				case 0x07:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[%x] = deltimer (%x)\n"), b, deltimer);
#endif
					v[b] = deltimer;

					PC += 2;
					return 1;
				}

				case 0x0A:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("Get Keypress\n"));
#endif
					if (key)
					{
						for (int i = 0; i < 16; i++) {
							if (key & (1 << i)) {
								v[b] = i;
								break;
							}
						}

						PC += 2;
					}

					return 1;
				}

				case 0x15:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("deltimer = v[%x] (%x)\n"), b, v[b]);
#endif
					deltimer = v[b];

					PC += 2;
					return 1;
				}

				case 0x18:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("sndtimer = v[%x] (%x)\n"), b, v[b]);
#endif
					sndtimer = v[b];

					PC += 2;
					return 1;
				}

				case 0x1E:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("I = v[%x] (%x)\n"), b, v[b]);
#endif
					ia += v[b];
					ia &= 0xfff;

					PC += 2;
					return 1;
				}

				case 0x29:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("Set I to loc. of fonts\n"));
#endif
					ia = 0x10A0 + (v[b] * 5);

					PC += 2;
					return 1;
				}

				case 0x30:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("Set I to loc. of fonts (Super)\n"));
#endif
					ia = 0x1000 + (v[b] * 10);

					PC += 2;
					return 1;
				}

				case 0x33:
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("Generate BCD of %2.2x at I: %X\n"), v[b], ia);
#endif
					mem[ia+0] = (v[b] / 100);
					mem[ia+1] = (v[b] % 100) / 10;
					mem[ia+2] = (v[b] % 10);

					PC += 2;
					return 1;
				}

				case 0x55:	// SChip only
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("mem[%x + x] = v[x] (x < %x)\n"), ia, b + 1);
#endif
					memcpy (mem + ia, v, b + 1);

					if (!game_type)
						ia += b + 1;

					PC += 2;
					return 1;
				}

				case 0x65:	// SChip only
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[x] = mem[%x + x] (i < %x)\n"), ia, b + 1);
#endif
					memcpy (v, mem + ia, b + 1);

					if (!game_type)
						ia += b + 1;

					PC += 2;
					return 1;
				}

				case 0x75:	// Loopz only
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[x] -> HP48 flags (x < %x)\n"), (b & 7));
#endif
					memcpy (hpr, v, (b & 7) + 1);

					PC += 2;
					return 1;
				}

				case 0x85:	// Loopz only
				{
#ifdef debug
					bprintf (PRINT_NORMAL, _T("v[x] <- HP48 flags (x < %x)\n"), (b & 7));
#endif
					memcpy (v, hpr, (b & 7) + 1);

					PC += 2;
					return 1;
				}
			}
#ifdef debug
			bprintf (PRINT_NORMAL, _T("Undocumented opcode (nop)\n"));
#endif
			PC += 2;
			return 1;
		}
	}

#ifdef debug
	bprintf (PRINT_NORMAL, _T("Undocumented opcode (nop)\n"));
#endif

	PC += 2;
	return 1;
}


int chip8opcodes(int run_x_ops)
{
	while (1)
	{
		if (run_x_ops == 0)
			break;

		if (opcode_do((mem[PC] << 8) | mem[PC+1]) == 0) {
			break;
		}

		if (SP > 0x0f) {
#ifdef debug
			bprintf (PRINT_NORMAL, _T("Stack overflow\n"));
#endif
			chip8_Reset();
			break;
		}

		run_x_ops--;
	}

	return 0;
}


//----------------------------------------------------------------------------------------
// general functions


int chip8_Reset()
{
	memset (screen, 0, screen_size);
	memset (mem + 0x200 + nC8Len, 0, (0x1000 - (nC8Len + 0x200)));

	srand ( time(NULL) );

	draw_mode = 0;
	PC = 0x0200;
	key = 0;
	ia = 0;
	SP = 0x0f;
	memset(stack, 0, 16);
	memset(v, 0, 16);
	memset (hpr, 0, 8);

	// Hack for Loopz
	hpr[0] = chip8Dip[1] & 0x0f;		// difficulty 0-9
	hpr[1] = 0xAA;
	hpr[2] = 0xAA;

	deltimer = 0;
	sndtimer = 0;

	return 0;
}


int chip8Init()
{
	game_type = (BurnDrvGetHardwareCode() >> 15) & 1;	// 0 for Chip-8, 1 for Super Chip

#ifndef debug
	if (BurnDrvGetHardwareCode() & 0x6000)			// Hybrid & Chip-8x games don't work
		return 1;
#endif

	screen_size = 64 * 32;

	if (game_type)
	{
		screen_size = 128 * 64;
	}

	key = 0;

	// get rom length
	{
		struct BurnRomInfo ri;
		BurnDrvGetRomInfo(&ri, 0);
		nC8Len = ri.nLen;
	}

	mem = (unsigned char*)malloc( 0x1100 );
	screen = (unsigned char*)malloc( screen_size );

	// make sure memory space is 00's
	memset (mem, 0, 0x1100); 

	// load rom
	if (BurnLoadRom(mem + 0x200, 0, 1))
		return 1;

	// store fonts past the end of the memory space
	for (int a = 0; a < 0xA0; a++)
	{
		mem[0x1000 + a] = fonts[a / 2]; // schip fonts
	}

	memcpy (mem + 0x10A0, fonts, 	 0x50); // chip8 fonts

	// reset the chip
	chip8_Reset();

	return 0;
}


int chip8Exit()
{
	game_type = 0;
	draw_mode = 0;
	key = 0;
	nC8Len = 0;
	screen_size = 0;

	free (mem);
	free (screen);
	mem = NULL;
	screen = NULL;

	return 0;
}


int chip8Frame()
{
	// Reset chip8
	if (chip8Reset) {
		chip8_Reset();
		chip8Reset = 0;
	}

	key = 0;
	for (int i = 0; i < 16; i++) {
		if (chip8inp[i]) {
			key |= (1 << i);
			chip8inp[i] = 0;
		}
	}
 
	// Run opcodes
	chip8opcodes(8 << game_type);

	// delay timer 
	if (deltimer)
		deltimer--;

	// sound delay timer
	if (sndtimer) {
		sndtimer--;

		if (!sndtimer) {		// beep!
#ifdef USE_WINDOWS_BEEP
			MessageBeep(-1);
#endif
		}
	}

	// Draw frame
	if (pBurnDraw) {
		BurnClearScreen();
		chip8draw();
	}

	return 0;
}


//----------------------------------------------------------------------------------------
// Savestates


static int chip8Scan(int nAction,int *pnMin)
{
	struct BurnArea ba;

	if (pnMin) {						// Return minimum compatible version
		*pnMin = 0x029521;
	}

	if (nAction & ACB_MEMORY_RAM) {				// Scan all memory, devices & variables
		ba.Data		= mem + 0x200 + nC8Len;
		ba.nLen		= 0x1000 - (nC8Len + 0x200);
		ba.nAddress = 0;
		ba.szName	= "Chip-8 RAM";
		BurnAcb(&ba);

		ba.Data		= screen;
		ba.nLen		= screen_size;
		ba.nAddress = 0;
		ba.szName	= "Chip-8 Video";
		BurnAcb(&ba);

		ba.Data		= v;
		ba.nLen		= 0x000010;
		ba.nAddress = 0;
		ba.szName	= "Chip-8 Vx Registers";
		BurnAcb(&ba);

		ba.Data		= (unsigned char*)stack;
		ba.nLen		= 0x000020;
		ba.nAddress = 0;
		ba.szName	= "Chip-8 Stack";
		BurnAcb(&ba);

		ba.Data		= hpr;
		ba.nLen		= 0x000008;
		ba.nAddress = 0;
		ba.szName	= "HP48 Registers";
		BurnAcb(&ba);
	}

	if (nAction & ACB_DRIVER_DATA) {
		SCAN_VAR(PC);
		SCAN_VAR(key);
		SCAN_VAR(ia);
		SCAN_VAR(SP);
		SCAN_VAR(deltimer);
		SCAN_VAR(sndtimer);
		SCAN_VAR(draw_mode);
	}

	return 0;
}


//----------------------------------------------------------------------------------------
// Game drivers


// 15 Puzzle (alt)

static struct BurnRomInfo c8_a000RomDesc[] = {
	{ "15 Puzzle [Roger Ivie] (alt).c8",	0x0108,	0x30ce37b1, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a000);
STD_ROM_FN(c8_a000);

struct BurnDriver BurnDrvc8_a000 = {
	"15 Puzzle [Roger Ivie] (alt)", NULL, NULL, "19??",
	"15 Puzzle (alt) (Chip-8)\0", NULL, "Roger Ivie", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a000RomInfo, c8_a000RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// 15 Puzzle

static struct BurnRomInfo c8_a001RomDesc[] = {
	{ "15 Puzzle [Roger Ivie].c8",	0x0180,	0x4e8693f1, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a001);
STD_ROM_FN(c8_a001);

struct BurnDriver BurnDrvc8_a001 = {
	"15 Puzzle [Roger Ivie]", NULL, NULL, "19??",
	"15 Puzzle (Chip-8)\0", NULL, "Roger Ivie", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a001RomInfo, c8_a001RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Addition Problems

static struct BurnRomInfo c8_a002RomDesc[] = {
	{ "Addition Problems [Paul C. Moews].c8",	0x00A8,	0xc20dc1ab, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a002);
STD_ROM_FN(c8_a002);

struct BurnDriver BurnDrvc8_a002 = {
	"Addition Problems [Paul C. Moews]", NULL, NULL, "19??",
	"Addition Problems (Chip-8)\0", NULL, "Paul C. Moews", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a002RomInfo, c8_a002RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Airplane

static struct BurnRomInfo c8_a003RomDesc[] = {
	{ "Airplane.c8",	0x0164,	0x6fd89b3d, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a003);
STD_ROM_FN(c8_a003);

struct BurnDriver BurnDrvc8_a003 = {
	"Airplane", NULL, NULL, "19??",
	"Airplane (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a003RomInfo, c8_a003RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Alien

static struct BurnRomInfo c8_a004RomDesc[] = {
	{ "Alien [Jonas Lindstedt].sc",	0x0326,	0xb8d5810b, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a004);
STD_ROM_FN(c8_a004);

struct BurnDriver BurnDrvc8_a004 = {
	"Alien [Jonas Lindstedt]", NULL, NULL, "19??",
	"Alien (Super Chip)\0", NULL, "Jonas Lindstedt", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a004RomInfo, c8_a004RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Animal Race

static struct BurnRomInfo c8_a005RomDesc[] = {
	{ "Animal Race [Brian Astle].c8",	0x04AA,	0x6465acef, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a005);
STD_ROM_FN(c8_a005);

struct BurnDriver BurnDrvc8_a005 = {
	"Animal Race [Brian Astle]", NULL, NULL, "19??",
	"Animal Race (Chip-8)\0", NULL, "Brian Astle", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a005RomInfo, c8_a005RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Ant - In Search of Coke

static struct BurnRomInfo c8_a006RomDesc[] = {
	{ "Ant - In Search of Coke [Erin S. Catto].sc",	0x0C7C,	0x4ad6578d, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a006);
STD_ROM_FN(c8_a006);

struct BurnDriver BurnDrvc8_a006 = {
	"Ant - In Search of Coke [Erin S. Catto]", NULL, NULL, "19??",
	"Ant - In Search of Coke (Super Chip)\0", NULL, "Erin S. Catto", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a006RomInfo, c8_a006RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Bingo (hybrid)

static struct BurnRomInfo c8_a007RomDesc[] = {
	{ "Bingo [Andrew Modla] (hybrid).c8",	0x0256,	0x00ef988f, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a007);
STD_ROM_FN(c8_a007);

struct BurnDriver BurnDrvc8_a007 = {
	"Bingo [Andrew Modla] (hybrid)", NULL, NULL, "19??",
	"Bingo (hybrid) (Chip-8)\0", NULL, "Andrew Modla", "Chip-8",
	NULL, NULL, NULL, NULL,
	0, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_HYBRID,
	NULL, c8_a007RomInfo, c8_a007RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Biorhythm

static struct BurnRomInfo c8_a008RomDesc[] = {
	{ "Biorhythm [Jef Winsor].c8",	0x038E,	0xb197ce7a, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a008);
STD_ROM_FN(c8_a008);

struct BurnDriver BurnDrvc8_a008 = {
	"Biorhythm [Jef Winsor]", NULL, NULL, "19??",
	"Biorhythm (Chip-8)\0", NULL, "Jef Winsor", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a008RomInfo, c8_a008RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Blackjack (hybrid)

static struct BurnRomInfo c8_a009RomDesc[] = {
	{ "Blackjack [Andrew Modla] (hybrid).c8",	0x048E,	0xdaed7dc5, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a009);
STD_ROM_FN(c8_a009);

struct BurnDriver BurnDrvc8_a009 = {
	"Blackjack [Andrew Modla] (hybrid)", NULL, NULL, "19??",
	"Blackjack (hybrid) (Chip-8)\0", NULL, "Andrew Modla", "Chip-8",
	NULL, NULL, NULL, NULL,
	0, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_HYBRID,
	NULL, c8_a009RomInfo, c8_a009RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Blinky (alt)

static struct BurnRomInfo c8_a00aRomDesc[] = {
	{ "Blinky [Hans Christian Egeberg] (alt).c8",	0x081E,	0x6ea76947, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a00a);
STD_ROM_FN(c8_a00a);

struct BurnDriver BurnDrvc8_a00a = {
	"Blinky [Hans Christian Egeberg] (alt)", NULL, NULL, "1990",
	"Blinky (alt) (Chip-8)\0", NULL, "Hans Christian Egeberg", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a00aRomInfo, c8_a00aRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Blinky

static struct BurnRomInfo c8_a00bRomDesc[] = {
	{ "Blinky [Hans Christian Egeberg].c8",	0x0934,	0x9d307e90, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a00b);
STD_ROM_FN(c8_a00b);

struct BurnDriver BurnDrvc8_a00b = {
	"Blinky [Hans Christian Egeberg] (c8)", NULL, NULL, "1991",
	"Blinky (Chip-8)\0", NULL, "Hans Christian Egeberg", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a00bRomInfo, c8_a00bRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Blinky

static struct BurnRomInfo c8_a00cRomDesc[] = {
	{ "Blinky [Hans Christian Egeberg].sc",	0x09E0,	0x94274048, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a00c);
STD_ROM_FN(c8_a00c);

struct BurnDriver BurnDrvc8_a00c = {
	"Blinky [Hans Christian Egeberg] (sc)", NULL, NULL, "1991",
	"Blinky (Super Chip)\0", NULL, "Hans Christian Egeberg", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a00cRomInfo, c8_a00cRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Blitz

static struct BurnRomInfo c8_a00dRomDesc[] = {
	{ "Blitz [David Winter].c8",	0x0187,	0xd106c808, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a00d);
STD_ROM_FN(c8_a00d);

struct BurnDriver BurnDrvc8_a00d = {
	"Blitz [David Winter]", NULL, NULL, "19??",
	"Blitz (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a00dRomInfo, c8_a00dRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Blockout.

static struct BurnRomInfo c8_a00eRomDesc[] = {
	{ "Blockout [Steve Houk].c8x",	0x0192,	0x4846d1c7, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a00e);
STD_ROM_FN(c8_a00e);

// program starts at 0x300

struct BurnDriver BurnDrvc8_a00e = {
	"Blockout [Steve Houk]", NULL, NULL, "19??",
	"Blockout (Chip-8 X)\0", NULL, "Steve Houk", "Chip-8 X",
	NULL, NULL, NULL, NULL,
	0, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_CHIP8X,
	NULL, c8_a00eRomInfo, c8_a00eRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// BMP Viewer - Flip-8 logo

static struct BurnRomInfo c8_a00fRomDesc[] = {
	{ "BMP Viewer - Flip-8 logo [newsdee].sc",	0x0430,	0x2d2136a4, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a00f);
STD_ROM_FN(c8_a00f);

struct BurnDriver BurnDrvc8_a00f = {
	"BMP Viewer - Flip-8 logo [newsdee]", NULL, NULL, "19??",
	"BMP Viewer - Flip-8 logo (Super Chip)\0", NULL, "newsdee", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a00fRomInfo, c8_a00fRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// BMP Viewer - Hello (C8 example)

static struct BurnRomInfo c8_a010RomDesc[] = {
	{ "BMP Viewer - Hello (C8 example) [hap].c8",	0x0130,	0x80cb3466, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a010);
STD_ROM_FN(c8_a010);

struct BurnDriver BurnDrvc8_a010 = {
	"BMP Viewer - Hello (C8 example) [hap]", NULL, NULL, "19??",
	"BMP Viewer - Hello (C8 example) (Chip-8)\0", NULL, "hap", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a010RomInfo, c8_a010RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// BMP Viewer - Kyori (SC example)

static struct BurnRomInfo c8_a011RomDesc[] = {
	{ "BMP Viewer - Kyori (SC example) [hap].sc",	0x0430,	0x6a28bf95, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a011);
STD_ROM_FN(c8_a011);

struct BurnDriver BurnDrvc8_a011 = {
	"BMP Viewer - Kyori (SC example) [hap]", NULL, NULL, "19??",
	"BMP Viewer - Kyori (SC example) (Super Chip)\0", NULL, "hap", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a011RomInfo, c8_a011RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// BMP Viewer - Let's Chip-8!

static struct BurnRomInfo c8_a012RomDesc[] = {
	{ "BMP Viewer - Let's Chip-8! [Koppepan].sc",	0x0430,	0xce0df8fd, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a012);
STD_ROM_FN(c8_a012);

struct BurnDriver BurnDrvc8_a012 = {
	"BMP Viewer - Let's Chip-8! [Koppepan]", NULL, NULL, "19??",
	"BMP Viewer - Let's Chip-8! (Super Chip)\0", NULL, "Koppepan", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a012RomInfo, c8_a012RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// BMP Viewer

static struct BurnRomInfo c8_a013RomDesc[] = {
	{ "BMP Viewer [hap].sc",	0x0030,	0xb3448bc6, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a013);
STD_ROM_FN(c8_a013);

struct BurnDriver BurnDrvc8_a013 = {
	"BMP Viewer [hap]", NULL, NULL, "19??",
	"BMP Viewer (Super Chip)\0", NULL, "hap", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a013RomInfo, c8_a013RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Boot-128 (hybrid)

static struct BurnRomInfo c8_a014RomDesc[] = {
	{ "Boot-128 (hybrid).c8",	0x0080,	0x5df0d62c, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a014);
STD_ROM_FN(c8_a014);

struct BurnDriver BurnDrvc8_a014 = {
	"Boot-128 (hybrid)", NULL, NULL, "19??",
	"Boot-128 (hybrid) (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	0, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_HYBRID,
	NULL, c8_a014RomInfo, c8_a014RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Bowling

static struct BurnRomInfo c8_a015RomDesc[] = {
	{ "Bowling [Gooitzen van der Wal].c8",	0x04AA,	0x0aeff5a0, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a015);
STD_ROM_FN(c8_a015);

struct BurnDriver BurnDrvc8_a015 = {
	"Bowling [Gooitzen van der Wal]", NULL, NULL, "19??",
	"Bowling (Chip-8)\0", NULL, "Gooitzen van der Wal", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a015RomInfo, c8_a015RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Breakout (Brix hack)

static struct BurnRomInfo c8_a016RomDesc[] = {
	{ "Breakout (Brix hack) [David Winter].c8",	0x0118,	0xa6bca0f7, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a016);
STD_ROM_FN(c8_a016);

struct BurnDriver BurnDrvc8_a016 = {
	"Breakout (Brix hack) [David Winter]", NULL, NULL, "19??",
	"Breakout (Brix hack) (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a016RomInfo, c8_a016RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Brick (Brix hack)

static struct BurnRomInfo c8_a017RomDesc[] = {
	{ "Brick (Brix hack).c8",	0x011E,	0x3bfced42, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a017);
STD_ROM_FN(c8_a017);

struct BurnDriver BurnDrvc8_a017 = {
	"Brick (Brix hack)", NULL, NULL, "19??",
	"Brick (Brix hack) (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a017RomInfo, c8_a017RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Brix

static struct BurnRomInfo c8_a018RomDesc[] = {
	{ "Brix [Andreas Gustafsson].c8",	0x0118,	0xaaa44d0b, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a018);
STD_ROM_FN(c8_a018);

struct BurnDriver BurnDrvc8_a018 = {
	"Brix [Andreas Gustafsson]", NULL, NULL, "19??",
	"Brix (Chip-8)\0", NULL, "Andreas Gustafsson", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a018RomInfo, c8_a018RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Car Race Demo

static struct BurnRomInfo c8_a019RomDesc[] = {
	{ "Car Race Demo [Erik Bryntse].sc",	0x0094,	0x2ca57d57, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a019);
STD_ROM_FN(c8_a019);

struct BurnDriver BurnDrvc8_a019 = {
	"Car Race Demo [Erik Bryntse]", NULL, NULL, "19??",
	"Car Race Demo (Super Chip)\0", NULL, "Erik Bryntse", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a019RomInfo, c8_a019RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Car

static struct BurnRomInfo c8_a01aRomDesc[] = {
	{ "Car [Klaus von Sengbusch].sc",	0x0140,	0x57092130, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a01a);
STD_ROM_FN(c8_a01a);

struct BurnDriver BurnDrvc8_a01a = {
	"Car [Klaus von Sengbusch]", NULL, NULL, "1994",
	"Car (Super Chip)\0", NULL, "Klaus von Sengbusch", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a01aRomInfo, c8_a01aRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Cave

static struct BurnRomInfo c8_a01bRomDesc[] = {
	{ "Cave.c8",	0x0372,	0x3bc80ce8, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a01b);
STD_ROM_FN(c8_a01b);

struct BurnDriver BurnDrvc8_a01b = {
	"Cave", NULL, NULL, "19??",
	"Cave (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a01bRomInfo, c8_a01bRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Chip8 emulator Logo

static struct BurnRomInfo c8_a01cRomDesc[] = {
	{ "Chip8 emulator Logo [Garstyciuks].c8",	0x0120,	0x1c5735aa, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a01c);
STD_ROM_FN(c8_a01c);

struct BurnDriver BurnDrvc8_a01c = {
	"Chip8 emulator Logo [Garstyciuks]", NULL, NULL, "19??",
	"Chip8 emulator Logo (Chip-8)\0", NULL, "Garstyciuks", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a01cRomInfo, c8_a01cRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Chip8 Picture

static struct BurnRomInfo c8_a01dRomDesc[] = {
	{ "Chip8 Picture.c8",	0x00A4,	0x9e738d35, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a01d);
STD_ROM_FN(c8_a01d);

struct BurnDriver BurnDrvc8_a01d = {
	"Chip8 Picture", NULL, NULL, "19??",
	"Chip8 Picture (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a01dRomInfo, c8_a01dRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Connect 4

static struct BurnRomInfo c8_a01eRomDesc[] = {
	{ "Connect 4 [David Winter].c8",	0x00C2,	0x9858889b, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a01e);
STD_ROM_FN(c8_a01e);

struct BurnDriver BurnDrvc8_a01e = {
	"Connect 4 [David Winter]", NULL, NULL, "19??",
	"Connect 4 (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a01eRomInfo, c8_a01eRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Deflection

static struct BurnRomInfo c8_a01fRomDesc[] = {
	{ "Deflection [John Fort].c8",	0x0400,	0x3b2aea72, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a01f);
STD_ROM_FN(c8_a01f);

struct BurnDriver BurnDrvc8_a01f = {
	"Deflection [John Fort]", NULL, NULL, "19??",
	"Deflection (Chip-8)\0", NULL, "John Fort", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a01fRomInfo, c8_a01fRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Emutest

static struct BurnRomInfo c8_a020RomDesc[] = {
	{ "Emutest [hap].sc",	0x0055,	0xa25e5635, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a020);
STD_ROM_FN(c8_a020);

struct BurnDriver BurnDrvc8_a020 = {
	"Emutest [hap]", NULL, NULL, "19??",
	"Emutest (Super Chip)\0", NULL, "hap", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a020RomInfo, c8_a020RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Field! (alt)

static struct BurnRomInfo c8_a021RomDesc[] = {
	{ "Field! [Al Roland] (alt).sc",	0x02E0,	0xadf85a91, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a021);
STD_ROM_FN(c8_a021);

struct BurnDriver BurnDrvc8_a021 = {
	"Field! [Al Roland] (alt)", NULL, NULL, "19??",
	"Field! (alt) (Super Chip)\0", NULL, "Al Roland", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a021RomInfo, c8_a021RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Field!

static struct BurnRomInfo c8_a022RomDesc[] = {
	{ "Field! [Al Roland].sc",	0x035C,	0x663e94c4, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a022);
STD_ROM_FN(c8_a022);

struct BurnDriver BurnDrvc8_a022 = {
	"Field! [Al Roland]", NULL, NULL, "19??",
	"Field! (Super Chip)\0", NULL, "Al Roland", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a022RomInfo, c8_a022RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Figures

static struct BurnRomInfo c8_a023RomDesc[] = {
	{ "Figures.c8",	0x0122,	0x67a9c567, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a023);
STD_ROM_FN(c8_a023);

struct BurnDriver BurnDrvc8_a023 = {
	"Figures", NULL, NULL, "19??",
	"Figures (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a023RomInfo, c8_a023RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Filter

static struct BurnRomInfo c8_a024RomDesc[] = {
	{ "Filter.c8",	0x00C6,	0xfb592cc5, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a024);
STD_ROM_FN(c8_a024);

struct BurnDriver BurnDrvc8_a024 = {
	"Filter", NULL, NULL, "19??",
	"Filter (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a024RomInfo, c8_a024RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Fishie

static struct BurnRomInfo c8_a025RomDesc[] = {
	{ "Fishie [hap].c8",	0x00A0,	0x06fe7c7d, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a025);
STD_ROM_FN(c8_a025);

struct BurnDriver BurnDrvc8_a025 = {
	"Fishie [hap]", NULL, NULL, "19??",
	"Fishie (Chip-8)\0", NULL, "hap", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a025RomInfo, c8_a025RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Font Test

static struct BurnRomInfo c8_a026RomDesc[] = {
	{ "Font Test [newsdee].sc",	0x0110,	0x7d738242, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a026);
STD_ROM_FN(c8_a026);

struct BurnDriver BurnDrvc8_a026 = {
	"Font Test [newsdee]", NULL, NULL, "19??",
	"Font Test (Super Chip)\0", NULL, "newsdee", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a026RomInfo, c8_a026RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Guess (alt)

static struct BurnRomInfo c8_a027RomDesc[] = {
	{ "Guess [David Winter] (alt).c8",	0x0094,	0x432e2fe1, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a027);
STD_ROM_FN(c8_a027);

struct BurnDriver BurnDrvc8_a027 = {
	"Guess [David Winter] (alt)", NULL, NULL, "19??",
	"Guess (alt) (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a027RomInfo, c8_a027RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Guess

static struct BurnRomInfo c8_a028RomDesc[] = {
	{ "Guess [David Winter].c8",	0x0096,	0x0501cecb, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a028);
STD_ROM_FN(c8_a028);

struct BurnDriver BurnDrvc8_a028 = {
	"Guess [David Winter]", NULL, NULL, "19??",
	"Guess (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a028RomInfo, c8_a028RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// H. Piper

static struct BurnRomInfo c8_a029RomDesc[] = {
	{ "H. Piper [Paul Raines].sc",	0x0724,	0xc4fe1d2c, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a029);
STD_ROM_FN(c8_a029);

struct BurnDriver BurnDrvc8_a029 = {
	"H. Piper [Paul Raines]", NULL, NULL, "1991",
	"H. Piper (Super Chip)\0", NULL, "Paul Raines", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a029RomInfo, c8_a029RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Hex Mixt

static struct BurnRomInfo c8_a02aRomDesc[] = {
	{ "Hex Mixt.sc",	0x0034,	0xfb3d5918, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a02a);
STD_ROM_FN(c8_a02a);

struct BurnDriver BurnDrvc8_a02a = {
	"Hex Mixt", NULL, NULL, "19??",
	"Hex Mixt (Super Chip)\0", NULL, NULL, "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a02aRomInfo, c8_a02aRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Hidden

static struct BurnRomInfo c8_a02bRomDesc[] = {
	{ "Hidden [David Winter].c8",	0x0352,	0x61861ae5, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a02b);
STD_ROM_FN(c8_a02b);

struct BurnDriver BurnDrvc8_a02b = {
	"Hidden [David Winter]", NULL, NULL, "19??",
	"Hidden (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a02bRomInfo, c8_a02bRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// IBM Logo

static struct BurnRomInfo c8_a02cRomDesc[] = {
	{ "IBM Logo.c8",	0x0084,	0xc46ca868, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a02c);
STD_ROM_FN(c8_a02c);

struct BurnDriver BurnDrvc8_a02c = {
	"IBM Logo", NULL, NULL, "19??",
	"IBM Logo (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a02cRomInfo, c8_a02cRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Joust (alt)

static struct BurnRomInfo c8_a02dRomDesc[] = {
	{ "Joust [Erin S. Catto] (alt).sc",	0x0946,	0x3e9b0905, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a02d);
STD_ROM_FN(c8_a02d);

struct BurnDriver BurnDrvc8_a02d = {
	"Joust [Erin S. Catto] (alt)", NULL, NULL, "19??",
	"Joust (alt) (Super Chip)\0", NULL, "Erin S. Catto", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a02dRomInfo, c8_a02dRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Joust

static struct BurnRomInfo c8_a02eRomDesc[] = {
	{ "Joust [Erin S. Catto].sc",	0x0946,	0xa3d9307f, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a02e);
STD_ROM_FN(c8_a02e);

struct BurnDriver BurnDrvc8_a02e = {
	"Joust [Erin S. Catto]", NULL, NULL, "19??",
	"Joust (Super Chip)\0", NULL, "Erin S. Catto", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a02eRomInfo, c8_a02eRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Kaleidoscope

static struct BurnRomInfo c8_a02fRomDesc[] = {
	{ "Kaleidoscope [Joseph Weisbecker].c8",	0x007A,	0xc73ba60c, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a02f);
STD_ROM_FN(c8_a02f);

struct BurnDriver BurnDrvc8_a02f = {
	"Kaleidoscope [Joseph Weisbecker]", NULL, NULL, "19??",
	"Kaleidoscope (Chip-8)\0", NULL, "Joseph Weisbecker", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a02fRomInfo, c8_a02fRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Keypad Test

static struct BurnRomInfo c8_a030RomDesc[] = {
	{ "Keypad Test [hap].c8",	0x0072,	0x6e1d4e9b, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a030);
STD_ROM_FN(c8_a030);

struct BurnDriver BurnDrvc8_a030 = {
	"Keypad Test [hap]", NULL, NULL, "19??",
	"Keypad Test (Chip-8)\0", NULL, "hap", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a030RomInfo, c8_a030RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Landing

static struct BurnRomInfo c8_a031RomDesc[] = {
	{ "Landing.c8",	0x0114,	0x804d282c, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a031);
STD_ROM_FN(c8_a031);

struct BurnDriver BurnDrvc8_a031 = {
	"Landing", NULL, NULL, "19??",
	"Landing (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a031RomInfo, c8_a031RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Laser

static struct BurnRomInfo c8_a032RomDesc[] = {
	{ "Laser.sc",	0x016E,	0x28e7d2ec, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a032);
STD_ROM_FN(c8_a032);

struct BurnDriver BurnDrvc8_a032 = {
	"Laser", NULL, NULL, "19??",
	"Laser (Super Chip)\0", NULL, NULL, "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a032RomInfo, c8_a032RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Line Demo

static struct BurnRomInfo c8_a033RomDesc[] = {
	{ "Line Demo.sc",	0x0016,	0xb4fbb350, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a033);
STD_ROM_FN(c8_a033);

struct BurnDriver BurnDrvc8_a033 = {
	"Line Demo", NULL, NULL, "19??",
	"Line Demo (Super Chip)\0", NULL, NULL, "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a033RomInfo, c8_a033RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Loopz (with difficulty select)

static struct BurnRomInfo c8_a034RomDesc[] = {
	{ "Loopz (with difficulty select) [hap].sc",	0x0E00,	0xd4a91d15, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a034);
STD_ROM_FN(c8_a034);

struct BurnDriver BurnDrvc8_a034 = {
	"Loopz (with difficulty select) [hap]", NULL, NULL, "19??",
	"Loopz (with difficulty select) (Super Chip)\0", NULL, "hap", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a034RomInfo, c8_a034RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Loopz

static struct BurnRomInfo c8_a035RomDesc[] = {
	{ "Loopz [Andreas Daumann].sc",	0x0D9E,	0x6636b9dc, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a035);
STD_ROM_FN(c8_a035);

struct BurnDriver BurnDrvc8_a035 = {
	"Loopz [Andreas Daumann]", NULL, NULL, "19??",
	"Loopz (Super Chip)\0", NULL, "Andreas Daumann", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a035RomInfo, c8_a035RomName, chip8InputInfo, LoopzDIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Lunar Lander

static struct BurnRomInfo c8_a036RomDesc[] = {
	{ "Lunar Lander.c8",	0x0700,	0xf0ec9a3d, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a036);
STD_ROM_FN(c8_a036);

struct BurnDriver BurnDrvc8_a036 = {
	"Lunar Lander", NULL, NULL, "19??",
	"Lunar Lander (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a036RomInfo, c8_a036RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Magic Square

static struct BurnRomInfo c8_a037RomDesc[] = {
	{ "Magic Square [David Winter].sc",	0x027D,	0x1a7f6694, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a037);
STD_ROM_FN(c8_a037);

struct BurnDriver BurnDrvc8_a037 = {
	"Magic Square [David Winter]", NULL, NULL, "19??",
	"Magic Square (Super Chip)\0", NULL, "David Winter", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a037RomInfo, c8_a037RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Matches

static struct BurnRomInfo c8_a038RomDesc[] = {
	{ "Matches.sc",	0x02AE,	0x72fcdd25, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a038);
STD_ROM_FN(c8_a038);

struct BurnDriver BurnDrvc8_a038 = {
	"Matches", NULL, NULL, "19??",
	"Matches (Super Chip)\0", NULL, NULL, "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a038RomInfo, c8_a038RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Maze (alt)

static struct BurnRomInfo c8_a039RomDesc[] = {
	{ "Maze [David Winter] (alt).c8",	0x0026,	0x39199fe2, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a039);
STD_ROM_FN(c8_a039);

struct BurnDriver BurnDrvc8_a039 = {
	"Maze [David Winter] (alt)", NULL, NULL, "19??",
	"Maze (alt) (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a039RomInfo, c8_a039RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Maze

static struct BurnRomInfo c8_a03aRomDesc[] = {
	{ "Maze [David Winter].c8",	0x0022,	0x37a658a2, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a03a);
STD_ROM_FN(c8_a03a);

struct BurnDriver BurnDrvc8_a03a = {
	"Maze [David Winter] (c8)", NULL, NULL, "19??",
	"Maze (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a03aRomInfo, c8_a03aRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Maze

static struct BurnRomInfo c8_a03bRomDesc[] = {
	{ "Maze [David Winter].sc",	0x0028,	0x5f3ae0c4, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a03b);
STD_ROM_FN(c8_a03b);

struct BurnDriver BurnDrvc8_a03b = {
	"Maze [David Winter] (sc)", NULL, NULL, "19??",
	"Maze (Super Chip)\0", NULL, "David Winter", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a03bRomInfo, c8_a03bRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Merlin

static struct BurnRomInfo c8_a03cRomDesc[] = {
	{ "Merlin [David Winter].c8",	0x0159,	0x1096c3d5, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a03c);
STD_ROM_FN(c8_a03c);

struct BurnDriver BurnDrvc8_a03c = {
	"Merlin [David Winter]", NULL, NULL, "19??",
	"Merlin (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a03cRomInfo, c8_a03cRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Message Center (hybrid)

static struct BurnRomInfo c8_a03dRomDesc[] = {
	{ "Message Center [Andrew Modla] (hybrid).c8",	0x03B7,	0x3b5df027, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a03d);
STD_ROM_FN(c8_a03d);

struct BurnDriver BurnDrvc8_a03d = {
	"Message Center [Andrew Modla] (hybrid)", NULL, NULL, "19??",
	"Message Center (hybrid) (Chip-8)\0", NULL, "Andrew Modla", "Chip-8",
	NULL, NULL, NULL, NULL,
	0, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_HYBRID,
	NULL, c8_a03dRomInfo, c8_a03dRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Mines! - The minehunter

static struct BurnRomInfo c8_a03eRomDesc[] = {
	{ "Mines! - The minehunter [David Winter].sc",	0x0753,	0x6976c87d, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a03e);
STD_ROM_FN(c8_a03e);

struct BurnDriver BurnDrvc8_a03e = {
	"Mines! - The minehunter [David Winter]", NULL, NULL, "19??",
	"Mines! - The minehunter (Super Chip)\0", NULL, "David Winter", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a03eRomInfo, c8_a03eRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Missile

static struct BurnRomInfo c8_a03fRomDesc[] = {
	{ "Missile [David Winter].c8",	0x00B4,	0x6e485c29, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a03f);
STD_ROM_FN(c8_a03f);

struct BurnDriver BurnDrvc8_a03f = {
	"Missile [David Winter]", NULL, NULL, "19??",
	"Missile (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a03fRomInfo, c8_a03fRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Most Dangerous Game

static struct BurnRomInfo c8_a040RomDesc[] = {
	{ "Most Dangerous Game [Peter Maruhnic].c8",	0x03F2,	0xe941c6d7, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a040);
STD_ROM_FN(c8_a040);

struct BurnDriver BurnDrvc8_a040 = {
	"Most Dangerous Game [Peter Maruhnic]", NULL, NULL, "19??",
	"Most Dangerous Game (Chip-8)\0", NULL, "Peter Maruhnic", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a040RomInfo, c8_a040RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Paddles

static struct BurnRomInfo c8_a041RomDesc[] = {
	{ "Paddles.c8",	0x0230,	0x5c786254, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a041);
STD_ROM_FN(c8_a041);

struct BurnDriver BurnDrvc8_a041 = {
	"Paddles", NULL, NULL, "19??",
	"Paddles (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a041RomInfo, c8_a041RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Pinball (hybrid)

static struct BurnRomInfo c8_a042RomDesc[] = {
	{ "Pinball [Andrew Modla] (hybrid).c8",	0x048A,	0x06577021, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a042);
STD_ROM_FN(c8_a042);

struct BurnDriver BurnDrvc8_a042 = {
	"Pinball [Andrew Modla] (hybrid)", NULL, NULL, "19??",
	"Pinball (hybrid) (Chip-8)\0", NULL, "Andrew Modla", "Chip-8",
	NULL, NULL, NULL, NULL,
	0, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_HYBRID,
	NULL, c8_a042RomInfo, c8_a042RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Pong (1 player)

static struct BurnRomInfo c8_a043RomDesc[] = {
	{ "Pong (1 player).c8",	0x00F6,	0x841fde23, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a043);
STD_ROM_FN(c8_a043);

struct BurnDriver BurnDrvc8_a043 = {
	"Pong (1 player)", NULL, NULL, "19??",
	"Pong (1 player) (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a043RomInfo, c8_a043RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Pong 2 (Pong hack)

static struct BurnRomInfo c8_a044RomDesc[] = {
	{ "Pong 2 (Pong hack) [David Winter].c8",	0x0126,	0xac46b66d, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a044);
STD_ROM_FN(c8_a044);

struct BurnDriver BurnDrvc8_a044 = {
	"Pong 2 (Pong hack) [David Winter]", NULL, NULL, "19??",
	"Pong 2 (Pong hack) (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a044RomInfo, c8_a044RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Pong (alt)

static struct BurnRomInfo c8_a045RomDesc[] = {
	{ "Pong [Paul Vervalin] (alt).c8",	0x0108,	0x69970ad2, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a045);
STD_ROM_FN(c8_a045);

struct BurnDriver BurnDrvc8_a045 = {
	"Pong [Paul Vervalin] (alt)", NULL, NULL, "19??",
	"Pong (alt) (Chip-8)\0", NULL, "Paul Vervalin", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a045RomInfo, c8_a045RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Pong

static struct BurnRomInfo c8_a046RomDesc[] = {
	{ "Pong [Paul Vervalin].c8",	0x00F6,	0x7d75a857, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a046);
STD_ROM_FN(c8_a046);

struct BurnDriver BurnDrvc8_a046 = {
	"Pong [Paul Vervalin]", NULL, NULL, "19??",
	"Pong (Chip-8)\0", NULL, "Paul Vervalin", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a046RomInfo, c8_a046RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Programmable Spacefighters

static struct BurnRomInfo c8_a047RomDesc[] = {
	{ "Programmable Spacefighters [Jef Winsor].c8",	0x03FC,	0xcc8eec70, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a047);
STD_ROM_FN(c8_a047);

struct BurnDriver BurnDrvc8_a047 = {
	"Programmable Spacefighters [Jef Winsor]", NULL, NULL, "19??",
	"Programmable Spacefighters (Chip-8)\0", NULL, "Jef Winsor", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a047RomInfo, c8_a047RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Puzzle

static struct BurnRomInfo c8_a048RomDesc[] = {
	{ "Puzzle.c8",	0x00B8,	0x040ca946, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a048);
STD_ROM_FN(c8_a048);

struct BurnDriver BurnDrvc8_a048 = {
	"Puzzle", NULL, NULL, "19??",
	"Puzzle (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a048RomInfo, c8_a048RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Reversi

static struct BurnRomInfo c8_a049RomDesc[] = {
	{ "Reversi [Philip Baltzer].c8",	0x0242,	0x02393966, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a049);
STD_ROM_FN(c8_a049);

struct BurnDriver BurnDrvc8_a049 = {
	"Reversi [Philip Baltzer]", NULL, NULL, "19??",
	"Reversi (Chip-8)\0", NULL, "Philip Baltzer", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a049RomInfo, c8_a049RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Robot

static struct BurnRomInfo c8_a04aRomDesc[] = {
	{ "Robot.sc",	0x005A,	0x6a980263, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a04a);
STD_ROM_FN(c8_a04a);

struct BurnDriver BurnDrvc8_a04a = {
	"Robot", NULL, NULL, "19??",
	"Robot (Super Chip)\0", NULL, NULL, "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a04aRomInfo, c8_a04aRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Rocket Launch

static struct BurnRomInfo c8_a04bRomDesc[] = {
	{ "Rocket Launch [Jonas Lindstedt].c8",	0x01EE,	0xbb286fea, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a04b);
STD_ROM_FN(c8_a04b);

struct BurnDriver BurnDrvc8_a04b = {
	"Rocket Launch [Jonas Lindstedt]", NULL, NULL, "19??",
	"Rocket Launch (Chip-8)\0", NULL, "Jonas Lindstedt", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a04bRomInfo, c8_a04bRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Rocket

static struct BurnRomInfo c8_a04cRomDesc[] = {
	{ "Rocket.c8",	0x0070,	0x027e5abb, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a04c);
STD_ROM_FN(c8_a04c);

struct BurnDriver BurnDrvc8_a04c = {
	"Rocket", NULL, NULL, "19??",
	"Rocket (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a04cRomInfo, c8_a04cRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Rush Hour

static struct BurnRomInfo c8_a04dRomDesc[] = {
	{ "Rush Hour [hap].c8",	0x0DFE,	0xa423f9e7, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a04d);
STD_ROM_FN(c8_a04d);

struct BurnDriver BurnDrvc8_a04d = {
	"Rush Hour [hap]", NULL, NULL, "19??",
	"Rush Hour (Chip-8)\0", NULL, "hap", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a04dRomInfo, c8_a04dRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Scroll Test (modified)

static struct BurnRomInfo c8_a04eRomDesc[] = {
	{ "Scroll Test (modified) [Garstyciuks].sc",	0x0026,	0xfef65454, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a04e);
STD_ROM_FN(c8_a04e);

struct BurnDriver BurnDrvc8_a04e = {
	"Scroll Test (modified) [Garstyciuks]", NULL, NULL, "19??",
	"Scroll Test (modified) (Super Chip)\0", NULL, "Garstyciuks", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a04eRomInfo, c8_a04eRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Scroll Test

static struct BurnRomInfo c8_a04fRomDesc[] = {
	{ "Scroll Test.sc",	0x005A,	0xf85f1566, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a04f);
STD_ROM_FN(c8_a04f);

struct BurnDriver BurnDrvc8_a04f = {
	"Scroll Test", NULL, NULL, "19??",
	"Scroll Test (Super Chip)\0", NULL, NULL, "Super Chip",
	NULL, NULL, NULL, NULL,
	0, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a04fRomInfo, c8_a04fRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Sequence Shoot

static struct BurnRomInfo c8_a050RomDesc[] = {
	{ "Sequence Shoot [Joyce Weisbecker].c8",	0x0144,	0x5a83ff48, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a050);
STD_ROM_FN(c8_a050);

struct BurnDriver BurnDrvc8_a050 = {
	"Sequence Shoot [Joyce Weisbecker]", NULL, NULL, "19??",
	"Sequence Shoot (Chip-8)\0", NULL, "Joyce Weisbecker", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a050RomInfo, c8_a050RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Single Dragon (Bomber Section)

static struct BurnRomInfo c8_a051RomDesc[] = {
	{ "Single Dragon (Bomber Section) [David Nurser].sc",	0x0106,	0xc551af2f, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a051);
STD_ROM_FN(c8_a051);

struct BurnDriver BurnDrvc8_a051 = {
	"Single Dragon (Bomber Section) [David Nurser]", NULL, NULL, "19??",
	"Single Dragon (Bomber Section) (Super Chip)\0", NULL, "David Nurser", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a051RomInfo, c8_a051RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Single Dragon (Stages 1-2)

static struct BurnRomInfo c8_a052RomDesc[] = {
	{ "Single Dragon (Stages 1-2) [David Nurser].sc",	0x0A60,	0x1802d315, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a052);
STD_ROM_FN(c8_a052);

struct BurnDriver BurnDrvc8_a052 = {
	"Single Dragon (Stages 1-2) [David Nurser]", NULL, NULL, "19??",
	"Single Dragon (Stages 1-2) (Super Chip)\0", NULL, "David Nurser", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a052RomInfo, c8_a052RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Slide

static struct BurnRomInfo c8_a053RomDesc[] = {
	{ "Slide [Joyce Weisbecker].c8",	0x0184,	0x746a9de0, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a053);
STD_ROM_FN(c8_a053);

struct BurnDriver BurnDrvc8_a053 = {
	"Slide [Joyce Weisbecker]", NULL, NULL, "19??",
	"Slide (Chip-8)\0", NULL, "Joyce Weisbecker", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a053RomInfo, c8_a053RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Soccer

static struct BurnRomInfo c8_a054RomDesc[] = {
	{ "Soccer.c8",	0x014E,	0x017884e3, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a054);
STD_ROM_FN(c8_a054);

struct BurnDriver BurnDrvc8_a054 = {
	"Soccer", NULL, NULL, "19??",
	"Soccer (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a054RomInfo, c8_a054RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Sokoban (alt)

static struct BurnRomInfo c8_a055RomDesc[] = {
	{ "Sokoban [hap] (alt).sc",	0x0E00,	0xa3be203f, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a055);
STD_ROM_FN(c8_a055);

struct BurnDriver BurnDrvc8_a055 = {
	"Sokoban [hap] (alt)", NULL, NULL, "19??",
	"Sokoban (alt) (Super Chip)\0", NULL, "hap", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a055RomInfo, c8_a055RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Sokoban

static struct BurnRomInfo c8_a056RomDesc[] = {
	{ "Sokoban [hap].sc",	0x0DFF,	0x902da748, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a056);
STD_ROM_FN(c8_a056);

struct BurnDriver BurnDrvc8_a056 = {
	"Sokoban [hap]", NULL, NULL, "19??",
	"Sokoban (Super Chip)\0", NULL, "hap", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a056RomInfo, c8_a056RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Space Flight

static struct BurnRomInfo c8_a057RomDesc[] = {
	{ "Space Flight.c8",	0x02CC,	0xdbc74090, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a057);
STD_ROM_FN(c8_a057);

struct BurnDriver BurnDrvc8_a057 = {
	"Space Flight", NULL, NULL, "19??",
	"Space Flight (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a057RomInfo, c8_a057RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Space Invaders (alt)

static struct BurnRomInfo c8_a058RomDesc[] = {
	{ "Space Invaders [David Winter] (alt).c8",	0x0503,	0xead625b8, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a058);
STD_ROM_FN(c8_a058);

struct BurnDriver BurnDrvc8_a058 = {
	"Space Invaders [David Winter] (alt)", NULL, NULL, "19??",
	"Space Invaders (alt) (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a058RomInfo, c8_a058RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Space Invaders

static struct BurnRomInfo c8_a059RomDesc[] = {
	{ "Space Invaders [David Winter].c8",	0x0515,	0x6ff0a017, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a059);
STD_ROM_FN(c8_a059);

struct BurnDriver BurnDrvc8_a059 = {
	"Space Invaders [David Winter]", NULL, NULL, "19??",
	"Space Invaders (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a059RomInfo, c8_a059RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Spacefight 2091

static struct BurnRomInfo c8_a05aRomDesc[] = {
	{ "Spacefight 2091 [Carsten Soerensen].sc",	0x0B17,	0x8819246c, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a05a);
STD_ROM_FN(c8_a05a);

struct BurnDriver BurnDrvc8_a05a = {
	"Spacefight 2091 [Carsten Soerensen]", NULL, NULL, "19??",
	"Spacefight 2091 (Super Chip)\0", NULL, "Carsten Soerensen", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a05aRomInfo, c8_a05aRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Squash

static struct BurnRomInfo c8_a05bRomDesc[] = {
	{ "Squash [David Winter].c8",	0x00D3,	0x801843e0, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a05b);
STD_ROM_FN(c8_a05b);

struct BurnDriver BurnDrvc8_a05b = {
	"Squash [David Winter]", NULL, NULL, "19??",
	"Squash (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a05bRomInfo, c8_a05bRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Sum Fun

static struct BurnRomInfo c8_a05cRomDesc[] = {
	{ "Sum Fun [Joyce Weisbecker].c8",	0x00B0,	0x51c9528b, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a05c);
STD_ROM_FN(c8_a05c);

struct BurnDriver BurnDrvc8_a05c = {
	"Sum Fun [Joyce Weisbecker]", NULL, NULL, "19??",
	"Sum Fun (Chip-8)\0", NULL, "Joyce Weisbecker", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a05cRomInfo, c8_a05cRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Syzygy

static struct BurnRomInfo c8_a05dRomDesc[] = {
	{ "Syzygy [Roy Trevino].c8",	0x03B2,	0x67e4bf9c, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a05d);
STD_ROM_FN(c8_a05d);

struct BurnDriver BurnDrvc8_a05d = {
	"Syzygy [Roy Trevino]", NULL, NULL, "1990",
	"Syzygy (Chip-8)\0", NULL, "Roy Trevino", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a05dRomInfo, c8_a05dRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Tank

static struct BurnRomInfo c8_a05eRomDesc[] = {
	{ "Tank.c8",	0x0230,	0xa929cb73, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a05e);
STD_ROM_FN(c8_a05e);

struct BurnDriver BurnDrvc8_a05e = {
	"Tank", NULL, NULL, "19??",
	"Tank (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a05eRomInfo, c8_a05eRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Tapeworm

static struct BurnRomInfo c8_a05fRomDesc[] = {
	{ "Tapeworm [JDR].c8",	0x011C,	0xc77a1852, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a05f);
STD_ROM_FN(c8_a05f);

struct BurnDriver BurnDrvc8_a05f = {
	"Tapeworm [JDR]", NULL, NULL, "19??",
	"Tapeworm (Chip-8)\0", NULL, "JDR", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a05fRomInfo, c8_a05fRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Test 128

static struct BurnRomInfo c8_a060RomDesc[] = {
	{ "Test 128.sc",	0x0118,	0xf0bead37, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a060);
STD_ROM_FN(c8_a060);

struct BurnDriver BurnDrvc8_a060 = {
	"Test 128", NULL, NULL, "19??",
	"Test 128 (Super Chip)\0", NULL, NULL, "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a060RomInfo, c8_a060RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Test

static struct BurnRomInfo c8_a061RomDesc[] = {
	{ "Test.sc",	0x0064,	0x3d48f74b, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a061);
STD_ROM_FN(c8_a061);

struct BurnDriver BurnDrvc8_a061 = {
	"Test", NULL, NULL, "19??",
	"Test (Super Chip)\0", NULL, NULL, "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a061RomInfo, c8_a061RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Tetris

static struct BurnRomInfo c8_a062RomDesc[] = {
	{ "Tetris [Fran Dachille].c8",	0x01EE,	0x0ce70772, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a062);
STD_ROM_FN(c8_a062);

struct BurnDriver BurnDrvc8_a062 = {
	"Tetris [Fran Dachille]", NULL, NULL, "19??",
	"Tetris (Chip-8)\0", NULL, "Fran Dachille", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a062RomInfo, c8_a062RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Tic-Tac-Toe

static struct BurnRomInfo c8_a063RomDesc[] = {
	{ "Tic-Tac-Toe [David Winter].c8",	0x01E6,	0x3a297a10, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a063);
STD_ROM_FN(c8_a063);

struct BurnDriver BurnDrvc8_a063 = {
	"Tic-Tac-Toe [David Winter]", NULL, NULL, "19??",
	"Tic-Tac-Toe (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a063RomInfo, c8_a063RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Timebomb

static struct BurnRomInfo c8_a064RomDesc[] = {
	{ "Timebomb.c8",	0x0090,	0x4db1c26c, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a064);
STD_ROM_FN(c8_a064);

struct BurnDriver BurnDrvc8_a064 = {
	"Timebomb", NULL, NULL, "19??",
	"Timebomb (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a064RomInfo, c8_a064RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Tron

static struct BurnRomInfo c8_a065RomDesc[] = {
	{ "Tron.c8",	0x017E,	0xe5b40a11, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a065);
STD_ROM_FN(c8_a065);

struct BurnDriver BurnDrvc8_a065 = {
	"Tron", NULL, NULL, "19??",
	"Tron (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a065RomInfo, c8_a065RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// U-Boat

static struct BurnRomInfo c8_a066RomDesc[] = {
	{ "U-Boat [Michael Kemper].sc",	0x07E0,	0xfbe18f8f, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a066);
STD_ROM_FN(c8_a066);

struct BurnDriver BurnDrvc8_a066 = {
	"U-Boat [Michael Kemper]", NULL, NULL, "19??",
	"U-Boat (Super Chip)\0", NULL, "Michael Kemper", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a066RomInfo, c8_a066RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// UFO

static struct BurnRomInfo c8_a067RomDesc[] = {
	{ "UFO.c8",	0x00E0,	0x331413e7, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a067);
STD_ROM_FN(c8_a067);

struct BurnDriver BurnDrvc8_a067 = {
	"UFO", NULL, NULL, "19??",
	"UFO (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a067RomInfo, c8_a067RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Vers

static struct BurnRomInfo c8_a068RomDesc[] = {
	{ "Vers [JMN].c8",	0x00E6,	0x0dbf7208, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a068);
STD_ROM_FN(c8_a068);

struct BurnDriver BurnDrvc8_a068 = {
	"Vers [JMN]", NULL, NULL, "1991",
	"Vers (Chip-8)\0", NULL, "JMN", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a068RomInfo, c8_a068RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Vertical Brix

static struct BurnRomInfo c8_a069RomDesc[] = {
	{ "Vertical Brix [Paul Robson].c8",	0x01FB,	0x608c6ab0, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a069);
STD_ROM_FN(c8_a069);

struct BurnDriver BurnDrvc8_a069 = {
	"Vertical Brix [Paul Robson]", NULL, NULL, "19??",
	"Vertical Brix (Chip-8)\0", NULL, "Paul Robson", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a069RomInfo, c8_a069RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Video Display Drawing Game (hybrid)

static struct BurnRomInfo c8_a06aRomDesc[] = {
	{ "Video Display Drawing Game [Joseph Weisbecker] (hybrid).c8",	0x0050,	0x1f91e53b, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a06a);
STD_ROM_FN(c8_a06a);

struct BurnDriver BurnDrvc8_a06a = {
	"Video Display Drawing Game [Joseph Weisbecker] (hybrid)", NULL, NULL, "19??",
	"Video Display Drawing Game (hybrid) (Chip-8)\0", NULL, "Joseph Weisbecker", "Chip-8",
	NULL, NULL, NULL, NULL,
	0, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_HYBRID,
	NULL, c8_a06aRomInfo, c8_a06aRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Wall

static struct BurnRomInfo c8_a06bRomDesc[] = {
	{ "Wall [David Winter].c8",	0x00E5,	0x64a9054b, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a06b);
STD_ROM_FN(c8_a06b);

struct BurnDriver BurnDrvc8_a06b = {
	"Wall [David Winter]", NULL, NULL, "19??",
	"Wall (Chip-8)\0", NULL, "David Winter", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a06bRomInfo, c8_a06bRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Wipe Off

static struct BurnRomInfo c8_a06cRomDesc[] = {
	{ "Wipe Off [Joseph Weisbecker].c8",	0x00CE,	0xb2696048, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a06c);
STD_ROM_FN(c8_a06c);

struct BurnDriver BurnDrvc8_a06c = {
	"Wipe Off [Joseph Weisbecker]", NULL, NULL, "19??",
	"Wipe Off (Chip-8)\0", NULL, "Joseph Weisbecker", "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a06cRomInfo, c8_a06cRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};


// Worm

static struct BurnRomInfo c8_a06dRomDesc[] = {
	{ "Worm [RB].sc",	0x0168,	0xfac6f666, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a06d);
STD_ROM_FN(c8_a06d);

struct BurnDriver BurnDrvc8_a06d = {
	"Worm [RB]", NULL, NULL, "19??",
	"Worm (Super Chip)\0", NULL, "RB", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a06dRomInfo, c8_a06dRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// Worms

static struct BurnRomInfo c8_a06eRomDesc[] = {
	{ "Worms.sc",	0x0086,	0xe0825d94, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a06e);
STD_ROM_FN(c8_a06e);

struct BurnDriver BurnDrvc8_a06e = {
	"Worms", NULL, NULL, "19??",
	"Worms (Super Chip)\0", NULL, NULL, "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a06eRomInfo, c8_a06eRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};


// X-Mirror

static struct BurnRomInfo c8_a06fRomDesc[] = {
	{ "X-Mirror.c8",	0x006A,	0x15965766, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a06f);
STD_ROM_FN(c8_a06f);

struct BurnDriver BurnDrvc8_a06f = {
	"X-Mirror", NULL, NULL, "19??",
	"X-Mirror (Chip-8)\0", NULL, NULL, "Chip-8",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC,
	NULL, c8_a06fRomInfo, c8_a06fRomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	64, 32, 2, 1
};



// IQ_132's SChip Test

static struct BurnRomInfo c8_a070RomDesc[] = {
	{ "iq_132 schip test.sc",	0x00E4,	0x4FD86003, BRF_ESS | BRF_PRG },
};

STD_ROM_PICK(c8_a070);
STD_ROM_FN(c8_a070);

struct BurnDriver BurnDrvc8_a070 = {
	"iq_132 schip test", NULL, NULL, "2007",
	"IQ_132's SChip Test (Super Chip)\0", NULL, "IQ_132", "Super Chip",
	NULL, NULL, NULL, NULL,
	BDF_GAME_WORKING, 1, HARDWARE_MISC_MISC | HARDWARE_CHIP8_SUPERCHIP,
	NULL, c8_a070RomInfo, c8_a070RomName, chip8InputInfo, chip8DIPInfo,
	chip8Init, chip8Exit, chip8Frame, chip8draw, chip8Scan, NULL,
	128, 64, 2, 1
};



